#!/usr/bin/python3

# Radio Buttons example with PyGObject and glade
# Author: Rafael Santos <rafael@sourcecode.net.br>

from gi.repository import Gtk
from itertools import permutations

class ManageWord(object):
    def __init__(self):
        # Instance of Gtk.Builder and add .glade file
        builder = Gtk.Builder()
        builder.add_from_file("radio_buttons.glade")
        # Get widgets
        self.window = builder.get_object("window")
        self.window.show()
        self.word_entry = builder.get_object("word_entry")
        self.text_view = builder.get_object("textview1")
        self.button = builder.get_object("process_button")
        self.inverter_radio = builder.get_object("inverter_radio")
        # Connect Signals
        builder.connect_signals({
                                "gtk_main_quit": Gtk.main_quit,
                                "process_button_clicked": self.process_option,
                                "on_word_entry_activate": self.process_option
                                })
    
    def invert_word(self, word):
        """ Invert some given word """        
        word = word[::-1]
        return word
        
    def get_anagram(self, word):
        """ Make anagrams from given word """
        # Be careful with this because you can get "low memory" error
        anagrams = ["".join(anagram) for anagram in permutations(word)]
        
        # Return only 100 word to prevent lack of memory
        return anagrams[:100]
                                                                          
    def get_active_radio(self):
        """ Get what button is activated from one radio button group"""
        # Get a list of buttons on group
        radio_buttons = self.inverter_radio.get_group()
        # Parse radio button list and check if is activated
        for radio in radio_buttons:
            # check if option is activated
            if radio.get_active():
                # Return the radio button label name
                return radio.get_label()
            
    def process_option(self, widget):
        """ Process option selected when process button is pressed """
        word = self.word_entry.get_text()
        # Get text_viwer buffer
        text_buffer = self.text_view.get_buffer()
        option = self.get_active_radio()
        # check option and get the result from option process
        if option == "Inverter":
            output = self.invert_word(word)        
        elif option == "Anagrama":
            # Get a list with anagrams
            list_output = self.get_anagram(word)
            # If output is a list we must create a string with list elements
            output = ""
            for line in list_output:
                output += line + "\n"
                
        elif option == "Letra Maiúscula":
            output = word.upper()
                            
        # Insert output on text view widget
        text_buffer.set_text(output)
        
if __name__ == "__main__":
    # Instantiate ManageWord class
    app = ManageWord()
    # Gtk main loop
    Gtk.main()
        
            
